# turnstone console

NODES
Loading cluster data...
WORKSTREAMS
STATE NAME MODEL NODE TASK TOKENS CTX
Open node UI
WORKSTREAMS
STATE NAME MODEL NODE TASK TOKENS CTX
USERS
USERNAME DISPLAY NAME CREATED ACTIONS
Loading users...
TOKENS Filter tokens by user
PREFIX NAME SCOPES CREATED EXPIRES ACTIONS
Select a user to view tokens
CHANNEL LINKS Filter channels by user
CHANNEL EXTERNAL ID LINKED ACTIONS
Select a user to view channel links
SCHEDULED TASKS
NAME TYPE SCHEDULE TARGET NEXT RUN STATUS ACTIONS
Loading schedules...
WATCHES Filter watches by node
NAME NODE COMMAND INTERVAL POLL CONDITION STATUS ACTIONS
Loading watches...
Loading...

## New Workstream

Node
Name optional Model optional Task optional — sent as first message

## Create User

Username Display name Password Confirm password

## Create API Token

Token name optional Scopes
Expiry optional

## Token Created

Copy this token now. It will not be shown again.

## Confirm

## Link Channel Account

Channel type
External user ID the user's ID on the platform

## New Schedule

Name Description optional Schedule type
Cron expression min hour day month weekday
Run at
Target
Node ID
Model optional Initial message Auto-approve tool calls

## Edit Schedule

Name Description Schedule type
Cron expression
Run at
Target
Node ID
Model Initial message Auto-approve tool calls Enabled

## Run History